#![allow(improper_ctypes)]

use fluence::marine;

fn main() {}

#[marine]
struct A(pub i32, pub u32);
